@@ -41,6 +41,8 @@ class SubConf(BaseConf):
     flow_control: bool = False
     pending_msgs_limit: Optional[int] = DEFAULT_JS_SUB_PENDING_MSGS_LIMIT
     pending_bytes_limit: Optional[int] = DEFAULT_JS_SUB_PENDING_BYTES_LIMIT
+    # 拉取模式的超时时间
+    pull_timeout: Optional[int] = 5
 
 
 class NatsConf(BaseConf):
