@@ -57,6 +57,7 @@ class Node(metaclass=abc.ABCMeta):
         # 建立链接
         nc = await nats.connect(servers=self.conf.nats.conn_conf.servers, **self.conf.nats.conn_conf.options)
         self.js = nc.jetstream(**self.conf.nats.stream_opts)
+        self.on_js_create(self.js)
         logger.debug("connect success!")
 
         # 构建kv
@@ -118,3 +119,12 @@ class Node(metaclass=abc.ABCMeta):
         :return:
         """
         return {"data": pmsg, "timeat": time.time()}
+
+    # --------
+    def on_js_create(self, js: nats.js.JetStreamContext):
+        """
+        jetstream创建时回调
+        :param js:
+        :return:
+        """
+        pass
